@@ -8,7 +8,7 @@ fn main() {
     App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(bevy_inspector_egui::InspectorPlugin::<RootUINode>::new())
-        .add_startup_system(setup.system())
+        .add_startup_system(setup)
         .run();
 }
 
