@@ -1,10 +1,10 @@
 use crate::options::{NumberAttributes, OptionAttributes, Vec2dAttributes};
-use crate::{Context, Inspectable};
+use crate::{utils, Context, Inspectable};
 use bevy::math::Vec4Swizzles;
 use bevy::pbr::{Clusters, CubemapVisibleEntities, StandardMaterial, VisiblePointLights};
 use bevy::render::primitives::{CubemapFrusta, Frustum, Plane};
 use bevy::render::render_resource::{PrimitiveTopology, ShaderImport};
-use bevy::render::view::VisibleEntities;
+use bevy::render::view::{RenderLayers, VisibleEntities};
 use bevy::{
     asset::HandleId,
     pbr::DirectionalLight,
@@ -20,7 +20,7 @@ use egui::Grid;
 impl_for_struct_delegate_fields!(
     PointLight:
     color,
-    intensity with NumberAttributes::positive().speed(1.0),
+    intensity with NumberAttributes::positive().with_speed(1.0),
     range with NumberAttributes::positive(),
     radius with NumberAttributes::positive(),
     shadows_enabled,
@@ -259,7 +259,7 @@ impl Inspectable for AmbientLight {
     type Attributes = <Color as Inspectable>::Attributes;
 
     fn ui(&mut self, ui: &mut egui::Ui, options: Self::Attributes, context: &mut Context) -> bool {
-        let brightness_attributes = NumberAttributes::positive().speed(0.01);
+        let brightness_attributes = NumberAttributes::positive().with_speed(0.01);
 
         self.color.ui(ui, options, context);
         self.brightness.ui(ui, brightness_attributes, context)
@@ -326,11 +326,11 @@ impl Inspectable for StandardMaterial {
                     ui.end_row();
 
                     ui.label("perceptual_roughness");
-                    changed |= self.perceptual_roughness.ui(ui, NumberAttributes::between(0.089, 1.0).speed(0.01), context);
+                    changed |= self.perceptual_roughness.ui(ui, NumberAttributes::between(0.089, 1.0).with_speed(0.01), context);
                     ui.end_row();
                     
                     ui.label("metallic");
-                    changed |= self.metallic.ui(ui, NumberAttributes::normalized().speed(0.01), context);
+                    changed |= self.metallic.ui(ui, NumberAttributes::normalized().with_speed(0.01), context);
                     ui.end_row();
 
                     ui.label("reflectance");
@@ -560,3 +560,49 @@ fn shader_import_to_string(import: &ShaderImport) -> String {
         ShaderImport::Custom(custom) => custom.clone(),
     }
 }
+
+impl Inspectable for RenderLayers {
+    type Attributes = ();
+
+    fn ui(&mut self, ui: &mut egui::Ui, _: Self::Attributes, context: &mut Context) -> bool {
+        let mut to_delete = None;
+
+        let mut changed = false;
+        for layer in self.iter() {
+            ui.horizontal(|ui| {
+                if utils::ui::label_button(ui, "✖", egui::Color32::RED) {
+                    to_delete = Some(layer);
+                }
+                ui.label(layer.to_string());
+            });
+        }
+
+        ui.horizontal(|ui| {
+            let id = context.id();
+            let mut new_layer: u8 = *ui
+                .memory()
+                .data
+                .get_temp_mut_or_insert_with(id, || self.iter().next().map_or(0, |val| val + 1));
+
+            if utils::ui::label_button(ui, "+", egui::Color32::GREEN) {
+                *self = self.with(new_layer);
+                changed = true;
+            }
+
+            if new_layer.ui(
+                ui,
+                NumberAttributes::default().with_max(RenderLayers::TOTAL_LAYERS as u8 - 1),
+                context,
+            ) {
+                ui.memory().data.insert_temp(id, new_layer);
+            }
+        });
+
+        if let Some(to_remove) = to_delete {
+            *self = self.without(to_remove);
+            changed = true;
+        }
+
+        changed
+    }
+}
