@@ -3,7 +3,7 @@ use bevy_egui::egui;
 
 use crate::Inspectable;
 
-use super::NumberAttributes;
+use super::{NumberAttributes, OptionAttributes};
 
 impl_for_simple_enum!(Display: Flex, None);
 impl_for_simple_enum!(bevy::ui::FocusPolicy: Block, Pass);
@@ -45,7 +45,7 @@ impl_for_struct_delegate_fields!(Text: sections, alignment);
 
 impl_for_struct_delegate_fields!(
     Style:
-    //display,
+    display,
     position_type,
     direction,
     flex_direction,
@@ -54,17 +54,17 @@ impl_for_struct_delegate_fields!(
     align_self,
     align_content,
     justify_content,
-    //position,
-    //margin,
-    //padding,
-    //border,
+    position,
+    margin,
+    padding,
+    border,
     flex_grow with NumberAttributes::positive(),
     flex_shrink with NumberAttributes::positive(),
     flex_basis,
     size,
     min_size,
     max_size,
-    // aspect_ratio,
+    aspect_ratio with OptionAttributes { deletable: true, replacement: Some(|| 1.), inner: NumberAttributes::positive() },
 );
 
 impl<T: Inspectable + Reflect + PartialEq> Inspectable for Size<T> {
@@ -93,6 +93,40 @@ impl<T: Inspectable + Reflect + PartialEq> Inspectable for Size<T> {
     }
 }
 
+impl<T: Inspectable + Reflect + PartialEq> Inspectable for Rect<T> {
+    type Attributes = T::Attributes;
+
+    fn ui(
+        &mut self,
+        ui: &mut bevy_egui::egui::Ui,
+        options: Self::Attributes,
+        context: &mut crate::Context,
+    ) -> bool {
+        let mut changed = false;
+        ui.vertical_centered(|ui| {
+            crate::egui::Grid::new(context.id()).show(ui, |ui| {
+                ui.label("left");
+                changed |= self.left.ui(ui, options.clone(), &mut context.with_id(0));
+                ui.end_row();
+
+                ui.label("right");
+                changed |= self.right.ui(ui, options.clone(), &mut context.with_id(1));
+                ui.end_row();
+
+                ui.label("top");
+                changed |= self.top.ui(ui, options.clone(), &mut context.with_id(2));
+                ui.end_row();
+
+                ui.label("bottom");
+                changed |= self.bottom.ui(ui, options.clone(), &mut context.with_id(3));
+                ui.end_row();
+            });
+            ui.separator();
+        });
+        changed
+    }
+}
+
 impl Inspectable for Val {
     type Attributes = ();
 
